.. documentation master file

.. include:: ../README.rst

.. toctree::
    :caption: Getting started
    :hidden:

    install
    usage
    contributing
    changelog

.. Warning: then usage of genindex is a hack to get a TOC entry, see
.. https://stackoverflow.com/a/42310803. This might break the usage of sphinx if
.. you want to create something different than HTML output.
.. toctree::
    :caption: API Documentation
    :hidden:

    api-smile
    genindex
